Enum class abstract

An interface for enumerated types in the protocol.

Clients may not extend, implement or mix-in this class.

Constructors

Enum()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the enumerated value. This should match the name of the static getter which provides access to this enumerated value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited