Notification class

A notification that can be sent to the server about an event that occurred.

Clients may not extend, implement or mix-in this class.

Constructors

Notification(String event, [Map<String, Object>? params])
Initialize a newly created Notification to have the given event name. If params is provided, it will be used as the params; otherwise no params will be used.
Notification.fromJson(Map json)
Initialize a newly created instance based on the given JSON data.
factory

Properties

event → String
The name of the event that triggered the notification.
final
hashCode → int
The hash code for this object.
no setterinherited
params → Map<String, Object>?
A table mapping the names of notification parameters to their values, or null if there are no notification parameters.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object>
Return a table representing the structure of the Json object that will be sent to the client to represent this response.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

EVENT → const String
The name of the JSON attribute containing the name of the event that triggered the notification.
PARAMS → const String
The name of the JSON attribute containing the result values.