DiagnosticMessage class

DiagnosticMessage

{
  "message": String
  "location": Location
}

Clients may not extend, implement or mix-in this class.

Constructors

DiagnosticMessage(String message, Location location)
DiagnosticMessage.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, {ClientUriConverter? clientUriConverter})
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
location ↔ Location
The location associated with or referenced by the message. Clients should provide the ability to navigate to the location.
getter/setter pair
message ↔ String
The message to be displayed to the user.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) → Map<String, Object>
Returns a JSON presentation of the object.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override