Location class

Location

{
  "file": FilePath
  "offset": int
  "length": int
  "startLine": int
  "startColumn": int
  "endLine": optional int
  "endColumn": optional int
}

Clients may not extend, implement or mix-in this class.

Constructors

Location(String file, int offset, int length, int startLine, int startColumn, {int? endLine, int? endColumn})
Location.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, {ClientUriConverter? clientUriConverter})
factory

Properties

endColumn ↔ int?
The one-based index of the column containing the character immediately following the range.
getter/setter pair
endLine ↔ int?
The one-based index of the line containing the character immediately following the range.
getter/setter pair
file ↔ String
The file containing the range.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
length ↔ int
The length of the range.
getter/setter pair
offset ↔ int
The offset of the range.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startColumn ↔ int
The one-based index of the column containing the first character of the range.
getter/setter pair
startLine ↔ int
The one-based index of the line containing the first character of the range.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) → Map<String, Object>
Returns a JSON presentation of the object.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override