NavigationTarget class

NavigationTarget

{
  "kind": ElementKind
  "fileIndex": int
  "offset": int
  "length": int
  "startLine": int
  "startColumn": int
  "codeOffset": optional int
  "codeLength": optional int
}

Clients may not extend, implement or mix-in this class.

Constructors

factory

Properties

codeLength ↔ int?
The length of the target code to which the user can navigate.
getter/setter pair
codeOffset ↔ int?
The offset of the target code to which the user can navigate.
getter/setter pair
fileIndex ↔ int
The index of the file (in the enclosing navigation response) to navigate to.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
kind ↔ ElementKind
The kind of the element.
getter/setter pair
length ↔ int
The length of the name of the target to which the user can navigate.
getter/setter pair
offset ↔ int
The offset of the name of the target to which the user can navigate.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startColumn ↔ int
The one-based index of the column containing the first character of the name of the target.
getter/setter pair
startLine ↔ int
The one-based index of the line containing the first character of the name of the target.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) → Map<String, Object>
Returns a JSON presentation of the object.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override