timestamp property
The timestamp, in milliseconds since the epoch, of when the message was requested to be printed.
Implementation
int timestamp;
The timestamp, in milliseconds since the epoch, of when the message was requested to be printed.
int timestamp;