RefactoringMethodParameter class

RefactoringMethodParameter

{
  "id": optional String
  "kind": RefactoringMethodParameterKind
  "type": String
  "name": String
  "parameters": optional String
}

Clients may not extend, implement or mix-in this class.

Constructors

RefactoringMethodParameter(RefactoringMethodParameterKind kind, String type, String name, {String? id, String? parameters})
RefactoringMethodParameter.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, {ClientUriConverter? clientUriConverter})
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
The unique identifier of the parameter. Clients may omit this field for the parameters they want to add.
getter/setter pair
kind ↔ RefactoringMethodParameterKind
The kind of the parameter.
getter/setter pair
name ↔ String
The name that should be given to the parameter.
getter/setter pair
parameters ↔ String?
The parameter list of the parameter's function type. If the parameter is not of a function type, this field will not be defined. If the function type has zero parameters, this field will have a value of '()'.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
The type that should be given to the parameter, or the return type of the parameter's function type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) → Map<String, Object>
Returns a JSON presentation of the object.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override