SourceChange class

SourceChange

{
  "message": String
  "edits": List<SourceFileEdit>
  "linkedEditGroups": List<LinkedEditGroup>
  "selection": optional Position
  "selectionLength": optional int
  "id": optional String
}

Clients may not extend, implement or mix-in this class.

Constructors

SourceChange(String message, {List<SourceFileEdit>? edits, List<LinkedEditGroup>? linkedEditGroups, Position? selection, int? selectionLength, String? id})
SourceChange.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, {ClientUriConverter? clientUriConverter})
factory

Properties

edits ↔ List<SourceFileEdit>
A list of the edits used to effect the change, grouped by file.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
id ↔ String?
The optional identifier of the change kind. The identifier remains stable even if the message changes, or is parameterized.
getter/setter pair
linkedEditGroups ↔ List<LinkedEditGroup>
A list of the linked editing groups used to customize the changes that were made.
getter/setter pair
message ↔ String
A human-readable description of the change to be applied.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selection ↔ Position?
The position that should be selected after the edits have been applied.
getter/setter pair
selectionLength ↔ int?
The length of the selection (starting at Position) that should be selected after the edits have been applied.
getter/setter pair

Methods

addEdit(String file, int fileStamp, SourceEdit edit, {bool insertBeforeExisting = false}) → void
Adds edit to the FileEdit for the given file.
addFileEdit(SourceFileEdit edit) → void
Adds the given FileEdit.
addLinkedEditGroup(LinkedEditGroup linkedEditGroup) → void
Adds the given LinkedEditGroup.
getFileEdit(String file) → SourceFileEdit?
Returns the FileEdit for the given file, maybe null.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) → Map<String, Object>
Returns a JSON presentation of the object.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override