AnalysisFoldingParams class

analysis.folding params

{
  "file": FilePath
  "regions": List<FoldingRegion>
}

Clients may not extend, implement or mix-in this class.

Constructors

AnalysisFoldingParams(String file, List<FoldingRegion> regions)
AnalysisFoldingParams.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, {ClientUriConverter? clientUriConverter})
factory
AnalysisFoldingParams.fromNotification(Notification notification, {ClientUriConverter? clientUriConverter})
factory

Properties

file ↔ String
The file containing the folding regions.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
regions ↔ List<FoldingRegion>
The folding regions contained in the file.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) → Map<String, Object>
Returns a JSON presentation of the object.
toNotification({ClientUriConverter? clientUriConverter}) → Notification
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override