AnalysisNavigationParams class

analysis.navigation params

{
  "file": FilePath
  "regions": List<NavigationRegion>
  "targets": List<NavigationTarget>
  "files": List<FilePath>
}

Clients may not extend, implement or mix-in this class.

Constructors

AnalysisNavigationParams(String file, List<NavigationRegion> regions, List<NavigationTarget> targets, List<String> files)
AnalysisNavigationParams.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, {ClientUriConverter? clientUriConverter})
factory
AnalysisNavigationParams.fromNotification(Notification notification, {ClientUriConverter? clientUriConverter})
factory

Properties

file ↔ String
The file containing the navigation regions.
getter/setter pair
files ↔ List<String>
The files containing navigation targets referenced in the file. They are referenced by NavigationTargets by their index in this array.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
regions ↔ List<NavigationRegion>
The navigation regions contained in the file.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targets ↔ List<NavigationTarget>
The navigation targets referenced in the file. They are referenced by NavigationRegions by their index in this array.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) → Map<String, Object>
Returns a JSON presentation of the object.
toNotification({ClientUriConverter? clientUriConverter}) → Notification
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override