AnalysisSetAnalysisRootsParams class
analysis.setAnalysisRoots params
{
"included": List<FilePath>
"excluded": List<FilePath>
}
Clients may not extend, implement or mix-in this class.
Constructors
-
AnalysisSetAnalysisRootsParams(List<
String> included, List<String> excluded) - AnalysisSetAnalysisRootsParams.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, {ClientUriConverter? clientUriConverter})
-
factory
- AnalysisSetAnalysisRootsParams.fromRequest(Request request, {ClientUriConverter? clientUriConverter})
-
factory
Properties
-
excluded
↔ List<
String> -
A list of the files and directories within the included directories that
should not be analyzed.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
-
included
↔ List<
String> -
A list of the files and directories that should be analyzed.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
{ClientUriConverter? clientUriConverter}) → Map< String, Object> - Returns a JSON presentation of the object.
-
toRequest(
String id, {ClientUriConverter? clientUriConverter}) → Request -
Return a request whose parameters are taken from this object and that has
the given
id. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override