AnalysisSetConfigurationsParams class

analysis.setConfigurations params

{
  "configurations": Map<FilePath, Map<String, PluginConfiguration>>
}

Clients may not extend, implement or mix-in this class.

Constructors

AnalysisSetConfigurationsParams(Map<String, Map<String, PluginConfiguration>> configurations)
AnalysisSetConfigurationsParams.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, {ClientUriConverter? clientUriConverter})
factory
AnalysisSetConfigurationsParams.fromRequest(Request request, {ClientUriConverter? clientUriConverter})
factory

Properties

configurations Map<String, Map<String, PluginConfiguration>>
A table mapping the path of the directory to a map of plugin names to their configurations.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) Map<String, Object>
Returns a JSON presentation of the object.
toRequest(String id, {ClientUriConverter? clientUriConverter}) Request
Return a request whose parameters are taken from this object and that has the given id.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override