configurations property
A table mapping the path of the directory to a map of plugin names to their configurations.
Implementation
Map<String, Map<String, PluginConfiguration>> configurations;
A table mapping the path of the directory to a map of plugin names to their configurations.
Map<String, Map<String, PluginConfiguration>> configurations;