ContextRoot class

ContextRoot

{
  "root": FilePath
  "exclude": List<FilePath>
  "optionsFile": optional FilePath
}

Clients may not extend, implement or mix-in this class.

Constructors

ContextRoot(String root, List<String> exclude, {String? optionsFile})
ContextRoot.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, {ClientUriConverter? clientUriConverter})
factory

Properties

exclude ↔ List<String>
A list of the absolute paths of files and directories within the root directory that should not be analyzed.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
optionsFile ↔ String?
The absolute path of the analysis options file that should be used to control the analysis of the files in the context.
getter/setter pair
root ↔ String
The absolute path of the root directory containing the files to be analyzed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) → Map<String, Object>
Returns a JSON presentation of the object.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override