InlineLocalVariableFeedback class

inlineLocalVariable feedback

{
  "name": String
  "occurrences": int
}

Clients may not extend, implement or mix-in this class.

Inheritance

Constructors

InlineLocalVariableFeedback(String name, int occurrences)
InlineLocalVariableFeedback.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, {ClientUriConverter? clientUriConverter})
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
name ↔ String
The name of the variable being inlined.
getter/setter pair
occurrences ↔ int
The number of times the variable occurs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) → Map<String, Object>
Returns a JSON presentation of the object.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override