InlineMethodOptions class

inlineMethod options

{
  "deleteSource": bool
  "inlineAll": bool
}

Clients may not extend, implement or mix-in this class.

Inheritance

Constructors

InlineMethodOptions(bool deleteSource, bool inlineAll)
InlineMethodOptions.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, {ClientUriConverter? clientUriConverter})
factory
InlineMethodOptions.fromRefactoringParams(EditGetRefactoringParams refactoringParams, Request request, {ClientUriConverter? clientUriConverter})
factory

Properties

deleteSource ↔ bool
True if the method being inlined should be removed. It is an error if this field is true and inlineAll is false.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
inlineAll ↔ bool
True if all invocations of the method should be inlined, or false if only the invocation site used to create this refactoring should be inlined.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) → Map<String, Object>
Returns a JSON presentation of the object.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override