PluginConfiguration class

PluginConfiguration

{
  "enabled": bool
  "diagnosticSeverities": Map<String, String>
}

Clients may not extend, implement or mix-in this class.

Constructors

PluginConfiguration(bool enabled, Map<String, String> diagnosticSeverities)
PluginConfiguration.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, {ClientUriConverter? clientUriConverter})
factory

Properties

diagnosticSeverities Map<String, String>
A map from diagnostic codes to their configured severities.
getter/setter pair
enabled bool
True if the plugin is enabled for this directory.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) Map<String, Object>
Returns a JSON presentation of the object.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override