PluginPrintParams class

plugin.print params

{
  "pluginPrint": PluginPrint
}

Clients may not extend, implement or mix-in this class.

Constructors

PluginPrintParams(PluginPrint pluginPrint)
PluginPrintParams.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, {ClientUriConverter? clientUriConverter})
factory
PluginPrintParams.fromNotification(Notification notification, {ClientUriConverter? clientUriConverter})
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
pluginPrint ↔ PluginPrint
Information about the message being printed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) → Map<String, Object>
Returns a JSON presentation of the object.
toNotification({ClientUriConverter? clientUriConverter}) → Notification
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override