PluginVersionCheckParams class

plugin.versionCheck params

{
  "byteStorePath": FilePath
  "sdkPath": FilePath
  "version": String
}

Clients may not extend, implement or mix-in this class.

Constructors

PluginVersionCheckParams(String byteStorePath, String sdkPath, String version)
PluginVersionCheckParams.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, {ClientUriConverter? clientUriConverter})
factory
PluginVersionCheckParams.fromRequest(Request request, {ClientUriConverter? clientUriConverter})
factory

Properties

byteStorePath ↔ String
The path to the directory containing the on-disk byte store that is to be used by any analysis drivers that are created.
getter/setter pair
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkPath ↔ String
The path to the directory containing the SDK that is to be used by any analysis drivers that are created.
getter/setter pair
version ↔ String
The version number of the plugin spec supported by the analysis server that is executing the plugin.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) → Map<String, Object>
Returns a JSON presentation of the object.
toRequest(String id, {ClientUriConverter? clientUriConverter}) → Request
Return a request whose parameters are taken from this object and that has the given id.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override