RefactoringOptions class

RefactoringOptions

{
}

Clients may not extend, implement or mix-in this class.

Implementers

Constructors

RefactoringOptions()
RefactoringOptions.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, RefactoringKind kind, {ClientUriConverter? clientUriConverter})
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) → Map<String, Object>
Returns a JSON presentation of the object.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override