FixContributor class abstract

An object used to produce fixes.

Clients may implement this class when implementing plugins.

Implementers

Constructors

FixContributor()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeFixes(covariant FixesRequest request, FixCollector collector) → Future<void>
Contribute fixes for the location in the file specified by the given request into the given collector.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited