DartHighlightsRequest class abstract

The information about a requested set of highlight regions when computing highlight regions in a .dart file.

Clients may not extend, implement or mix-in this class.

Implemented types

Constructors

DartHighlightsRequest()

Properties

hashCode → int
The hash code for this object.
no setterinherited
path → String
Return the path of the file for which highlight regions are being requested.
no setterinherited
resourceProvider → ResourceProvider
Return the resource provider associated with this request.
no setterinherited
result → ResolvedUnitResult
The analysis result for the file for which the highlight regions are being requested.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited