HighlightsContributor class abstract

An object used to produce highlight regions.

Clients may implement this class when implementing plugins.

Constructors

HighlightsContributor()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

computeHighlights(HighlightsRequest request, HighlightsCollector collector) → void
Contribute highlight regions into the given collector.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited