NavigationRequest class abstract

The information about a requested set of navigation information.

Clients may not extend, implement or mix-in this class.

Implementers

Constructors

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int?
Return the length of the region within the source for which navigation regions are being requested.
no setter
offset → int
Return the offset of the region within the source for which navigation regions are being requested.
no setter
path → String
Return the path of the file in which navigation regions are being requested.
no setter
resourceProvider → ResourceProvider
Return the resource provider associated with this request.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited