PluginPrint class

PluginPrint

{
  "pluginName": String
  "message": String
  "timestamp": int
}

Clients may not extend, implement or mix-in this class.

Constructors

PluginPrint(String pluginName, String message, int timestamp)
PluginPrint.fromJson(JsonDecoder jsonDecoder, String jsonPath, Object? json, {ClientUriConverter? clientUriConverter})
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
message String
The message which has been printed.
getter/setter pair
pluginName String
The name of the plugin which called 'print'.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
The timestamp, in milliseconds since the epoch, of when the message was requested to be printed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({ClientUriConverter? clientUriConverter}) Map<String, Object>
Returns a JSON presentation of the object.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override